@@ -1,5 +1,5 @@
 # localslackirc
-# Copyright (C) 2018-2023 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # localslackirc is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ import msgparsing
 from diff import seddiff
 
 
-VERSION = '1.24'
+VERSION = '1.27'
 
 
 class IrcDisconnectError(Exception): ...
@@ -192,7 +192,7 @@ class Client:
                 if not sl_chan.is_member:
                     continue
 
-                if sl_chan.is_mpim and (sl_chan.latest is None or sl_chan.latest.timestamp < mpim_cutoff):
+                if sl_chan.is_mpim and ((sl_chan.updated / 1000) < mpim_cutoff.timestamp()):
                     continue
 
                 channel_name = '#%s' % sl_chan.name_normalized
@@ -432,9 +432,12 @@ class Client:
             await self._sendreply(Replies.ERR_UNKNOWNCOMMAND, 'Syntax: /sendfile #channel filename')
             return
 
-        with open(filename, 'rb') as f:
-            content = f.read()
-            await self.send_file(params[1], content=content, filename=filename)
+        try:
+            with open(filename, 'rb') as f:
+                content = f.read()
+                await self.send_file(params[1], content=content, filename=filename)
+        except Exception as e:
+            await self._sendreply(Replies.ERR_FILEERROR, f'Error: {e}')
 
 
     async def send_file(self, bchannel_name: bytes, content: bytes, filename: str) -> bool:
@@ -877,7 +880,7 @@ class Client:
             await self._joined_parted(sl_ev, False)
         elif isinstance(sl_ev, slack.TopicChange):
             await self._sendreply(Replies.RPL_TOPIC, sl_ev.topic, ['#' + (await self.sl_client.get_channel(sl_ev.channel)).name])
-        elif isinstance(sl_ev, slack.GroupJoined):
+        elif isinstance(sl_ev, slack.GroupJoined) or isinstance(sl_ev, slack.MpimJoined):
             channel_name = '#%s' % sl_ev.channel.name_normalized
             await self._send_chan_info(channel_name.encode('utf-8'), sl_ev.channel)
 
@@ -947,7 +950,9 @@ def su() -> None:
 def main() -> None:
     su()
 
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        description='Creates an IRC server running locally, which acts as a gateway to slack for one user.'
+    )
     parser.add_argument('-v', '--version', action='version', version=f'''localslackirc {VERSION}''')
     parser.add_argument('-p', '--port', type=int, action='store', dest='port',
                                 default=9007, required=False,
