@@ -1,5 +1,5 @@
 # localslackirc
-# Copyright (C) 2018-2023 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # localslackirc is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -119,6 +119,9 @@ class Channel:
     is_group: bool = False
     is_mpim: bool = False
 
+    # Last updated?
+    updated: int = 0
+
     latest: Optional[LatestMessage] = None
 
     @property
@@ -165,6 +168,12 @@ class GroupJoined:
     channel: Channel
 
 
+@dataclass
+class MpimJoined:
+    type: Literal['mpim_joined']
+    channel: Channel
+
+
 @dataclass
 class MessageEdit:
     type: Literal['message']
@@ -327,6 +336,7 @@ SlackEvent = (
     Join|
     Leave|
     GroupJoined|
+    MpimJoined|
     UserTyping
 )
 
@@ -1019,7 +1029,7 @@ class Slack:
                 continue
 
             debug(event)
-            loadable_events = TopicChange|MessageBot|MessageEdit|MessageDelete|GroupJoined|Join|Leave|UserTyping
+            loadable_events = TopicChange|MessageBot|MessageEdit|MessageDelete|GroupJoined|Join|Leave|UserTyping|MpimJoined
             try:
                 ev: Optional[loadable_events] = self.tload(
                     event,
